@@ -7,6 +7,7 @@ from .proxies.module import ModuleProxy
 from .proxies.mock_chroot import MockChrootProxy
 from .proxies.project_chroot import ProjectChrootProxy
 from .proxies.build_chroot import BuildChrootProxy
+from .proxies.webhook import WebhookProxy
 
 
 class Client(object):
@@ -20,6 +21,7 @@ class Client(object):
         self.mock_chroot_proxy = MockChrootProxy(config)
         self.project_chroot_proxy = ProjectChrootProxy(config)
         self.build_chroot_proxy = BuildChrootProxy(config)
+        self.webhook_proxy = WebhookProxy(config)
 
     @classmethod
     def create_from_config_file(cls, path=None):
